@@ -18,14 +18,15 @@ logger = logging.getLogger('spreadsplug.djvubind')
 
 
 class DjvuBindPlugin(HookPlugin):
+    __name__ = 'djvubind'
+
     def output(self, path):
         logger.info("Assembling DJVU.")
-        img_dir = os.path.join(path, 'done')
-        djvu_file = os.path.join(path, 'out',
-                                 "{0}.djvu".format(os.path.basename(path)))
-        cmd = ["djvubind", img_dir]
-        if self.config['djvubind']['ocr'].get(unicode) == 'none':
+        img_dir = path / 'done'
+        djvu_file = path / 'out' / "{0}.djvu".format(path.name)
+        cmd = ["djvubind", unicode(img_dir)]
+        if not img_dir.glob("*.html"):
             cmd.append("--no-ocr")
         logger.debug("Running " + " ".join(cmd))
-        _ = subprocess.check_output(cmd, stderr=subprocess.STDOUT)
-        os.rename("book.djvu", djvu_file)
+        subprocess.check_output(cmd, stderr=subprocess.STDOUT)
+        os.rename("book.djvu", unicode(djvu_file))
